#ifndef SICHTSYSTEMGUI_H
#define SICHTSYSTEMGUI_H

#include <QtGui>
#include "ui_sichtsystemgui.h"

#include "visualGUI_DateTime.h"
#include "visualGUI_ObjectPosition.h"
#include "visualGUI_externalLinkVCL.h"
#include "visualGUI_externalDataContainer.h"

#include <osg/Math>


class SichtsystemGUI : public QMainWindow
{
	Q_OBJECT

public:
	SichtsystemGUI(QWidget *parent = 0, Qt::WFlags flags = 0);
	~SichtsystemGUI();
	
	/**
	* Fngt closeEvents ab um benutzerdefinierte Aktionen durchzufhren und den Event danach zu akzeptieren.
	* Zu den Aktionen gehrt das Speichern der Einstellungen, das Schliessen das Debugfensters etc.
	* @return void
	* @param event: Abzufangender CloseEvent
	*/
	void closeEvent( QCloseEvent *event );

	void setDebug(QTextEdit* debug_);

private:
	/**
	 * \brief Diese Funktion setzt die Dockwidgets zusammen
	 * 
	 */ 
	void setupDockWidgets();

	/**
	 * \brief Diese Funktion populiert die Toolbars mit den jeweiligen Actions.
	 * 
	 */ 
	void setupToolbars();



	Ui::SichtsystemGUIClass ui;

	/**
	 * Pointer auf das Debug-Feld
	 */ 
	QTextEdit* debug;

	/**
	 * Pointer auf den Process in dem der Helpviewer luft.
	 */
	QProcess *helpProcess;

	/**
	 * Pointer auf DateTimeWidget.
	 */
	visualGUI_DateTime* dateTimeWidget;

	visualGUI_ObjectPosition* objectPositionWidget;
	
	visualGUI_externalDataContainer* externalDataContainer;

	visualGUI_externalLinkVCL* externalLink;

	QTimer *externalLinkTimer;


private slots:
	void on_actionTriggerExternalLink_triggered();
	void on_actionToggle_bottom_right_corner_triggered();
	void on_actionToggle_bottom_left_corner_triggered();
	void on_actionToggle_top_right_corner_triggered();
	void on_actionToggle_top_left_corner_triggered();
	void on_actionAbout_This_Programm_triggered();
	void on_actionAbout_Qt_triggered();
};

#endif // SICHTSYSTEMGUI_H
